@@ -1,13 +1,13 @@
-import yaml
 import os
 
+import yaml
+
 from pipereport.base.templateregistry import BaseTemplateRegistry
-from pipereport.template.template import Template
 
 
 class FSTemplateRegistry(BaseTemplateRegistry):
 
-    def __init__(self, path, *args, **kwargs):
+    def __init__(self, *args, path=".", **kwargs):
         super().__init__(*args, **kwargs)
         self.path = path
 
